==> 0.1.0a.zip: menagerie_cookbook/shared/src/commonMain/kotlin/model/MexicanData.kt <==
package model

import recipeappkmp.shared.generated.resources.Res
import recipeappkmp.shared.generated.resources._10_strawberries
import kotlin.time.Duration

val mexicanList = listOf(
    Recipe (
        title = "Elote | Street Corn",
        description = "Grilled Street Corn with Cream Sauce and Chili Spices.",
        prepTime = Duration.parse("15m"),
        cookTime = Duration.parse("6m"),
        servings = "6 Ears",
        ingredients = listOf(
            "6 Medium Ears Sweet Corn",
            "½ Cup Mexican Crema, or Sour Cream",
            "½ Cup Mayonnaise",
            "½ Cup Cilantro, Chopped",
            "2 Cloves Garlic",
            "¼ Tbsp Chipotle Powder, or to taste",
            "2 tsp Lime Zest, grated",
            "2 Tbsp Lime Juice",
            "½ Cup Cotija Cheese, crumbled",
            "Lime Wedges, to serve"
        ),
        instructions = listOf(
            "In a bowl, whisk together the Crema [1/2 Cup], Mayonnaise [1/2 Cup], Cilantro [1/2 Cup], Garlic [2 Cloves], Chipotle Pepper [3/4 Tbsp], Lime Zest [2 Tsp] and Lime Juice [2 Tbsp]. Taste and season the mixture with Salt if needed. (Crema has a little Salt already, so add extra judiciously.) Set aside.",
            "Grill the Corn, about 3 minutes per side, until browned",
            "Slather with Crema Mixture, crumbled Cotija, and Chipotle Powder. Serve with Lime Wedges"

        ),
        tags = mapOf(
            "Mexican" to TagType.CUISINE,
            "Spicy" to TagType.FLAVOUR,
            "Grilled" to TagType.TECHNIQUE,
            "Appetizer" to TagType.COURSE,
        ),
        image = Res.drawable._10_strawberries
    )
)

==> 0.1.2a.zip: menagerie_cookbook/shared/src/commonMain/kotlin/model/MexicanData.kt <==
package model

import recipeappkmp.shared.generated.resources.Res
import recipeappkmp.shared.generated.resources._10_strawberries
import kotlin.time.Duration

val mexicanList = listOf(
    Recipe (
        title = "Elote | Street Corn",
        description = "Grilled Street Corn with Cream Sauce and Chili Spices.",
        prepTime = Duration.parse("15m"),
        cookTime = Duration.parse("6m"),
        servings = "6 Ears",
        ingredients = listOf(
            "6 Medium Ears Sweet Corn",
            "½ Cup Mexican Crema, or Sour Cream",
            "½ Cup Mayonnaise",
            "½ Cup Cilantro, Chopped",
            "2 Cloves Garlic",
            "¼ Tbsp Chipotle Powder, or to taste",
            "2 tsp Lime Zest, grated",
            "2 Tbsp Lime Juice",
            "½ Cup Cotija Cheese, crumbled",
            "Lime Wedges, to serve"
        ),
        instructions = listOf(
            "In a bowl, whisk together the Crema [1/2 Cup], Mayonnaise [1/2 Cup], Cilantro [1/2 Cup], Garlic [2 Cloves], Chipotle Pepper [3/4 Tbsp]," +
                    " Lime Zest [2 Tsp] and Lime Juice [2 Tbsp]. Taste and season the mixture with Salt if needed. (Crema has a little Salt already, so" +
                    " add extra judiciously.) Set aside.",
            "Grill the Corn, about 3 minutes per side, until browned",
            "Slather with Crema Mixture, crumbled Cotija, and Chipotle Powder. Serve with Lime Wedges"

        ),
        tags = mapOf(
            "Mexican" to TagType.CUISINE,
            "Spicy" to TagType.FLAVOUR,
            "Grilled" to TagType.TECHNIQUE,
            "Street Food" to TagType.TECHNIQUE,
            "Appetizer" to TagType.COURSE,
        ),
        image = Res.drawable._10_strawberries
    )
)
